#!/bin/bash
rm -f /usr/bin/multivnc_server
rm -f /usr/bin/multivnc_client
rm -ri /etc/multivnc/multivnc_server.conf
if [ ! -e /etc/multivnc/multivnc_server.conf ] ; then
  rm -rf /etc/multivnc
fi

rm -f /usr/share/locale/ja/LC_MESSAGES/multivnc_server.mo
rm -f /usr/share/locale/ja/LC_MESSAGES/multivnc_client.mo
rm -f /usr/share/locale/zh_CN/LC_MESSAGES/multivnc_server.mo
rm -f /usr/share/locale/zh_CN/LC_MESSAGES/multivnc_client.mo
rm -f /usr/share/locale/vi/LC_MESSAGES/multivnc_server.mo
rm -f /usr/share/locale/vi/LC_MESSAGES/multivnc_client.mo
rm -f /usr/share/locale/ro/LC_MESSAGES/multivnc_server.mo
rm -f /usr/share/locale/ro/LC_MESSAGES/multivnc_client.mo
echo "MultiVNC Uninstall COMPLETE!"
